@@ -1,8 +1,10 @@
 import json.decoder
 
 import requests
+from packaging.version import Version
 
 from akinoncli.core.exc import AkinonCLIError
+from akinoncli.core.version import get_version
 
 
 class AkinonResponse:
@@ -25,8 +27,6 @@ class AkinonCloudClient:
         "application_types": "applications/application_types/",
         "application_types_admin": "admin/application_types/",
         "application_types_admin_detail": "admin/application_types/{application_type_id}/",
-        "app_users": "applications/{app_id}/users/",
-        "clusters": "clusters/",
         "login": "users/login/",
         "projects": "projects/",
         "project_detail": "projects/{p_id}/",
@@ -43,11 +43,9 @@ class AkinonCloudClient:
         "public_keys": "users/public_keys/",
         "public_key_detail": "users/public_keys/{pk_id}/",
         "register": "users/register/",
-        "users": "users/",
-        "roles": "users/roles/",
         "domains": "accounts/domains/",
         "certificates": "accounts/domains/{domain_id}/certificates/",
-        "kube_metric_monitor": "clusters/{cluster}/monitor/{namespace}/",
+        "attach_certificate": "projects/{p_id}/project_apps/attach_certificate/",
     }
 
     def __init__(self, base_url, token):
@@ -60,6 +58,8 @@ class AkinonCloudClient:
         headers = headers or {}
         qs = qs or {}
         headers["Content-Type"] = "application/json"
+        headers["User-Agent"] = f"akinoncli {Version(get_version())}"
+
         if self.token:
             headers["Authorization"] = f"Token {self.token}"
         url = f"{self.URLS['base']}{self.URLS[url]}".format(**params)
@@ -90,9 +90,6 @@ class AkinonCloudClient:
     def login(self, data):
         return self._send_request("POST", "login", data=data)
 
-    def get_clusters(self):
-        return self._send_request("GET", "clusters")
-
     def get_projects(self, qs: dict):
         return self._send_request("GET", "projects", qs=qs)
 
@@ -138,12 +135,6 @@ class AkinonCloudClient:
     def get_app_version_logs(self, app_id, version_id):
         return self._send_request("GET", "app_version_logs", params={"app_id": app_id, "v_id": version_id})
 
-    def get_app_users(self, app_id):
-        return self._send_request("GET", "app_users", params={"app_id": app_id})
-
-    def create_app_user(self, app_id, data):
-        return self._send_request("POST", "app_users", params={"app_id": app_id}, data=data)
-
     def get_application_types(self, qs: dict):
         return self._send_request("GET", "application_types", qs=qs)
 
@@ -208,6 +199,15 @@ class AkinonCloudClient:
     def create_project_app(self, p_id, data):
         return self._send_request("POST", "project_apps", params={"p_id": p_id}, data=data)
 
+    def attach_certificate(self, project_id: str, data: dict):
+        response = self._send_request("POST", "attach_certificate", params={"p_id": project_id}, data=data)
+        if response.status_code == 404:
+            if response.data is None:
+                raise AkinonCLIError("Project App could not found.")
+            raise AkinonCLIError(str(response.data))
+
+        return response
+
     def deploy_project_app(self, p_id: int, pa_id: int, data: dict) -> AkinonResponse:
         response = self._send_request(
             "POST",
@@ -252,19 +252,6 @@ class AkinonCloudClient:
     def remove_public_key(self, pk_id):
         return self._send_request("DELETE", "public_key_detail", params={"pk_id": pk_id})
 
-    def get_users(self, qs=None):
-        qs = qs or {}
-        return self._send_request("GET", "users", qs=qs)
-
-    def create_user(self, data):
-        return self._send_request("POST", "users", data=data)
-
-    def get_roles(self):
-        return self._send_request("GET", "roles")
-
-    def create_role(self, data):
-        return self._send_request("POST", "roles", data=data)
-
     def get_domains(self, qs: dict):
         return self._send_request("GET", "domains", qs=qs)
 
@@ -276,11 +263,3 @@ class AkinonCloudClient:
 
     def create_certificate(self, domain_id, data):
         return self._send_request("POST", "certificates", data=data, params={'domain_id': domain_id})
-
-    def get_metrics(self, cluster: str, namespace: str, qs: dict):
-        return self._send_request(
-            "GET",
-            "kube_metric_monitor",
-            params={"cluster": cluster, "namespace": namespace},
-            qs=qs,
-        )
