@@ -1,14 +1,15 @@
-
 from cement import Controller, ex
 from cement.utils.version import get_version_banner
 
 from ..core.version import get_version
 
-
 VERSION_BANNER = """
 CLI for Akinon Cloud Commerce %s
 %s
-""" % (get_version(), get_version_banner())
+""" % (
+    get_version(),
+    get_version_banner(),
+)
 
 
 class Base(Controller):
@@ -21,10 +22,13 @@ class Base(Controller):
     @ex(
         help='Set URLCommand',
         arguments=[
-            (['url'], {
-                'help': 'Base URL',
-                'action': 'store',
-            }),
+            (
+                ['url'],
+                {
+                    'help': 'Base URL',
+                    'action': 'store',
+                },
+            ),
         ],
     )
     def set(self):
