@@ -1,6 +1,7 @@
-import os
-from datetime import datetime, timedelta, timezone
+import sys
+from datetime import datetime
 
+import urllib3.util
 from cement import Controller, ex, shell
 from cement.utils.version import get_version_banner
 
@@ -315,15 +316,16 @@ class ProjectApps(Controller):
         data = {'app': app_id}
         response = self.app.client.get_relatable_project_apps(app_id=app_id, project_id=p_id)
         if response.is_succeed and response.data:
-            app = response.data[0]['app']
+            application_type = response.data[0]['application_type']
             project_apps = response.data[0]['project_apps']
             if not project_apps:
                 self.app.render(
-                    f"App needs a {app['name']} app. Please install a {app['name']} first.", renderer_type='text'
+                    f"App needs a {application_type['name']} app. Please install a {application_type['name']} first.",
+                    renderer_type='text',
                 )
                 return
 
-            print(f"This application needs to be related with a {app['name']}.")
+            print(f"This application needs to be related with a {application_type['name']}.")
             options = []
             for project_app in project_apps:
                 options.append(str(project_app['pk']))
@@ -495,26 +497,35 @@ class ProjectApps(Controller):
                 },
             ),
             (
-                ['project_app_id'],
+                ['url'],
                 {
-                    'help': 'Project App ID',
+                    'help': 'Project App Url',
                     'action': 'store',
                 },
             ),
             (
-                ['certificate_id'],
+                ['fqdn'],
                 {
-                    'help': 'Certificate ID',
+                    'help': 'Certificate FQDN',
                     'action': 'store',
                 },
             ),
         ],
     )
     def attach_certificate(self):
-        p_id = self.app.pargs.project_id
-        pa_id = self.app.pargs.project_app_id
-        data = {'certificate': self.app.pargs.certificate_id}
-        response = self.app.client.update_project_app(p_id, pa_id, data=data)
+        project_id = self.app.pargs.project_id
+        url = urllib3.util.parse_url(self.app.pargs.url)
+        url = (url.scheme or 'https://') + url.host
+        fqdn = self.app.pargs.fqdn
+
+        data = {'fqdn': fqdn, 'url': url}
+
+        confirm = input('The certificate you specified will be attached to the project app. Are you sure? (Y/N)')
+
+        if confirm.capitalize() != 'Y':
+            sys.exit(0)
+
+        response = self.app.client.attach_certificate(project_id, data=data)
 
         if response.is_succeed:
             self.app.render("Certificate has been attached to project app.", renderer_type='text')
